@@ -1,9 +1,7 @@
-import numpy as np
-from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin
-from sklearn.utils.multiclass import check_classification_targets
-from sklearn.utils.validation import check_X_y, check_array, check_is_fitted
 from typing import List
 
+import numpy as np
+
 from imodels.rule_set.skope_rules import SkopeRulesClassifier
 from imodels.util.convert import itemsets_to_rules
 from imodels.util.extract import extract_fpgrowth
@@ -16,9 +14,11 @@ class FPSkopeClassifier(SkopeRulesClassifier):
     def __init__(self,
                  minsupport=0.1,
                  maxcardinality=2,
+                 disc_strategy='mdlp',
+                 disc_kwargs={},
                  verbose=False,
                  precision_min=0.5,
-                 recall_min=0.4,
+                 recall_min=0.01,
                  n_estimators=10,
                  max_samples=.8,
                  max_samples_features=1.,
@@ -44,6 +44,8 @@ class FPSkopeClassifier(SkopeRulesClassifier):
                          n_jobs,
                          random_state,
                          verbose)
+        self.disc_strategy = disc_strategy
+        self.disc_kwargs = disc_kwargs
         self.minsupport = minsupport
         self.maxcardinality = maxcardinality
         self.verbose = verbose
@@ -55,10 +57,12 @@ class FPSkopeClassifier(SkopeRulesClassifier):
 
     def _extract_rules(self, X, y) -> List[str]:
         itemsets = extract_fpgrowth(X, y,
-                                    feature_labels=self.feature_placeholders,
+                                    feature_names=self.feature_placeholders,
                                     minsupport=self.minsupport,
                                     maxcardinality=self.maxcardinality,
                                     undiscretized_features=self.undiscretized_features,
+                                    disc_strategy=self.disc_strategy,
+                                    disc_kwargs=self.disc_kwargs,
                                     verbose=self.verbose)[0]
         return [itemsets_to_rules(itemsets)], [np.arange(X.shape[0])], [np.arange(len(self.feature_names))]
 
